@@ -67,6 +67,39 @@ fill_advanced_table (Longcat *plugin,
         break;
     }
 
+  /* Username */
+  label = gtk_label_new ("Username");
+  g_object_set (label, "xalign", 0.0, NULL);
+  gtk_widget_show (label);
+
+  widget = GTK_WIDGET (g_object_new (RTCOM_TYPE_PARAM_STRING,
+          "field", "username",
+          "can-next", FALSE,
+          "visibility", TRUE,
+          "required", FALSE,
+          NULL));
+
+  rtcom_widget_set_account (RTCOM_WIDGET (widget),
+      RTCOM_ACCOUNT_ITEM (account));
+  gtk_widget_show (widget);
+
+  /* Disable auto-capitalisation/dictionary */
+  g_object_set (widget, "hildon-input-mode",
+      HILDON_GTK_INPUT_MODE_FULL, NULL);
+
+  gtk_table_attach (GTK_TABLE (table), label,
+      0, /* left */
+      1, /* right */
+      0, /* top */
+      1, /* bottom */
+      GTK_SHRINK | GTK_FILL, 0, 0, 0);
+  gtk_table_attach (GTK_TABLE (table), widget,
+      1, /* left */
+      2, /* right */
+      0, /* top */
+      1, /* bottom */
+      GTK_EXPAND | GTK_FILL, 0, 0, 0);
+
   /* Use SSL */
   widget = GTK_WIDGET (g_object_new (RTCOM_TYPE_PARAM_BOOL,
           "label", "Use SSL",
@@ -82,8 +115,8 @@ fill_advanced_table (Longcat *plugin,
   gtk_table_attach (GTK_TABLE (table), widget,
       0, /* left */
       2, /* right */
-      0, /* top */
-      1, /* bottom */
+      1, /* top */
+      2, /* bottom */
       GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
   hildon_check_button_set_active (HILDON_CHECK_BUTTON (widget),
@@ -113,8 +146,8 @@ fill_advanced_table (Longcat *plugin,
   gtk_table_attach (GTK_TABLE (table), label,
       0, /* left */
       1, /* right */
-      1, /* top */
-      2, /* bottom */
+      2, /* top */
+      3, /* bottom */
       GTK_SHRINK | GTK_FILL, 0, 0, 0);
 
   rtcom_widget_set_account (RTCOM_WIDGET (widget),
@@ -124,8 +157,8 @@ fill_advanced_table (Longcat *plugin,
   gtk_table_attach (GTK_TABLE (table), widget,
       1, /* left */
       2, /* right */
-      1, /* top */
-      2, /* bottom */
+      2, /* top */
+      3, /* bottom */
       GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
   /* Password */
@@ -146,8 +179,8 @@ fill_advanced_table (Longcat *plugin,
   gtk_table_attach (GTK_TABLE (table), label,
       0, /* left */
       1, /* right */
-      2, /* top */
-      3, /* bottom */
+      3, /* top */
+      4, /* bottom */
       GTK_SHRINK | GTK_FILL, 0, 0, 0);
 
   rtcom_widget_set_account (RTCOM_WIDGET (widget),
@@ -157,8 +190,8 @@ fill_advanced_table (Longcat *plugin,
   gtk_table_attach (GTK_TABLE (table), widget,
       1, /* left */
       2, /* right */
-      2, /* top */
-      3, /* bottom */
+      3, /* top */
+      4, /* bottom */
       GTK_EXPAND | GTK_FILL, 0, 0, 0);
 }
 
